==> lsws-5.4.9.tar.gz: lsws-5.4.9/admin/html/utility/build_php/buildconf.inc.php <==
<?php

define ('LEGAL', 1);
define ('TITLE', 'Compile PHP with LSAPI');
define ('OPTION_VERSION', 3);

define ('BUILD_DIR', $_SERVER['LS_SERVER_ROOT'] . 'phpbuild');
define ('LAST_CONF', BUILD_DIR . '/savedconfig.'); // actual file will include . php base version.

define ('DEFAULT_INSTALL_DIR', $_SERVER['LS_SERVER_ROOT'].'lsphp'); // actual dir will include . php base version.

$PHP_VER = array(
        '7'=>
        array(
            '7.4.4',
            '7.3.16',
            '7.2.29',
			'7.1.33',
			'7.0.33'),
        '5'=>
		 array(
		 	'5.6.40',
		 	'5.5.38',
		 	'5.4.45',
		 	'5.3.29',
			'5.2.17'));

define ('LSAPI_VERSION', '7.6');
define ('SUHOSIN_VERSION', '0.9.38');
define ('APC_VERSION', '3.1.9');		// http://pecl.php.net/package/APC
define ('XCACHE_VERSION', '3.2.0');		// http://xcache.lighttpd.net/
define ('MEMCACHE_VERSION', '2.2.7');	// http://pecl.php.net/package/memcache
define ('MEMCACHED_VERSION', '2.2.0'); // http://pecl.php.net/package/memcached
define ('MEMCACHED7_VERSION', '3.1.5'); // http://pecl.php.net/package/memcached for php7 only
define ('OPCACHE_VERSION', '7.0.5');	// http://pecl.php.net/package/ZendOpcache

$DEFAULT_PHP_PARAMS = array(
	'7' => '--with-mysqli --with-zlib --with-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-mbstring --with-iconv --with-mcrypt --with-pdo-mysql --enable-ftp --enable-zip --with-curl --enable-soap --enable-xml --enable-json  --with-openssl --enable-bcmath',
	'5' => '--with-mysqli --with-zlib --with-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-mbstring --with-iconv --with-mysql --with-mcrypt --with-pdo --with-pdo-mysql --enable-ftp --enable-zip --with-curl --enable-soap --enable-xml --enable-json  --with-openssl --enable-bcmath',
	'4' => '--with-mysql  --with-zlib --with-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-magic-quotes --enable-mbstring');


include_once( 'buildfunc.inc.php' );

==> lsws-6.0.12.tar.gz: lsws-6.0.12/admin/html/utility/build_php/buildconf.inc.php <==
<?php

define ('LEGAL', 1);
define ('TITLE', 'Compile PHP with LSAPI');
define ('OPTION_VERSION', 3);

define ('BUILD_DIR', $_SERVER['LS_SERVER_ROOT'] . 'phpbuild');
define ('LAST_CONF', BUILD_DIR . '/savedconfig.'); // actual file will include . php base version.

define ('DEFAULT_INSTALL_DIR', $_SERVER['LS_SERVER_ROOT'].'lsphp'); // actual dir will include . php base version.

$PHP_VER = [
	'8' => [
		'8.0.11'],
	'7' => [
		'7.4.24',
		'7.3.31',
		'7.2.34',
		'7.1.33',
		'7.0.33'],
	'5' => [
		'5.6.40',
		'5.5.38',
		'5.4.45',
		'5.3.29']
];

define ('LSAPI_VERSION', '7.9');
define ('SUHOSIN_VERSION', '0.9.38');
define ('APC_VERSION', '3.1.9');		// http://pecl.php.net/package/APC
define ('XCACHE_VERSION', '3.2.0');		// http://xcache.lighttpd.net/
define ('MEMCACHE_VERSION', '2.2.7');	// http://pecl.php.net/package/memcache
define ('MEMCACHED_VERSION', '2.2.0'); // http://pecl.php.net/package/memcached
define ('MEMCACHED7_VERSION', '3.1.5'); // http://pecl.php.net/package/memcached for php7 only
define ('OPCACHE_VERSION', '7.0.5');	// http://pecl.php.net/package/ZendOpcache

$DEFAULT_PHP_PARAMS = [
	'8' => '--with-mysqli --with-zlib --enable-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-mbstring --with-iconv --with-pdo-mysql --enable-ftp --with-zip --with-curl --enable-soap --enable-xml --with-openssl --enable-bcmath',
	'7' => '--with-mysqli --with-zlib --with-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-mbstring --with-iconv --with-mcrypt --with-pdo-mysql --enable-ftp --enable-zip --with-curl --enable-soap --enable-xml --enable-json  --with-openssl --enable-bcmath',
	'5' => '--with-mysqli --with-zlib --with-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-mbstring --with-iconv --with-mysql --with-mcrypt --with-pdo --with-pdo-mysql --enable-ftp --enable-zip --with-curl --enable-soap --enable-xml --enable-json  --with-openssl --enable-bcmath',
	'4' => '--with-mysql  --with-zlib --with-gd --enable-shmop --enable-sockets --enable-sysvsem --enable-sysvshm --enable-magic-quotes --enable-mbstring',
	];


include_once( 'buildfunc.inc.php' );
